@@ -1,4 +1,4 @@
-# Copyright (c) 2009, 2024, Oracle and/or its affiliates.
+# Copyright (c) 2009, 2025, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -57,7 +57,8 @@ from typing import (
 )
 
 from . import version
-from ._decorating import cmd_refresh_verify_options
+from ._decorating import cmd_refresh_verify_options, handle_read_write_timeout
+from ._scripting import get_local_infile_filenames
 from .abstracts import MySQLConnectionAbstract
 from .authentication import MySQLAuthenticator, get_auth_plugin
 from .constants import (
@@ -67,21 +68,16 @@ from .constants import (
     ServerCmd,
     ServerFlag,
     flag_is_set,
-    raise_warning_against_deprecated_cursor_class,
 )
 from .conversion import MySQLConverter
 from .cursor import (
     MySQLCursor,
     MySQLCursorBuffered,
     MySQLCursorBufferedDict,
-    MySQLCursorBufferedNamedTuple,
     MySQLCursorBufferedRaw,
     MySQLCursorDict,
-    MySQLCursorNamedTuple,
     MySQLCursorPrepared,
     MySQLCursorPreparedDict,
-    MySQLCursorPreparedNamedTuple,
-    MySQLCursorPreparedRaw,
     MySQLCursorRaw,
 )
 from .errors import (
@@ -101,7 +97,13 @@ from .logger import logger
 from .network import MySQLSocket, MySQLTCPSocket, MySQLUnixSocket
 from .opentelemetry.constants import OTEL_ENABLED
 from .opentelemetry.context_propagation import with_context_propagation
-from .protocol import MySQLProtocol
+from .protocol import (
+    EOF_STATUS,
+    ERR_STATUS,
+    LOCAL_INFILE_STATUS,
+    OK_STATUS,
+    MySQLProtocol,
+)
 from .types import (
     BinaryProtocolType,
     DescriptionType,
@@ -115,7 +117,6 @@ from .types import (
 )
 from .utils import (
     get_platform,
-    handle_read_write_timeout,
     int1store,
     int4store,
     lc_int,
@@ -211,7 +212,7 @@ class MySQLConnection(MySQLConnectionAbstract):
     def _do_handshake(self) -> None:
         """Get the handshake from the MySQL server"""
         packet = bytes(self._socket.recv())
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
 
         self._handshake = None
@@ -248,14 +249,14 @@ class MySQLConnection(MySQLConnectionAbstract):
             self._client_flags |= ClientFlag.SSL
 
         if handshake["capabilities"] & ClientFlag.PLUGIN_AUTH:
-            self.set_client_flags([ClientFlag.PLUGIN_AUTH])
+            self.client_flags = [ClientFlag.PLUGIN_AUTH]
 
         if handshake["capabilities"] & ClientFlag.CLIENT_QUERY_ATTRIBUTES:
             self._query_attrs_supported = True
-            self.set_client_flags([ClientFlag.CLIENT_QUERY_ATTRIBUTES])
+            self.client_flags = [ClientFlag.CLIENT_QUERY_ATTRIBUTES]
 
         if handshake["capabilities"] & ClientFlag.MULTI_FACTOR_AUTHENTICATION:
-            self.set_client_flags([ClientFlag.MULTI_FACTOR_AUTHENTICATION])
+            self.client_flags = [ClientFlag.MULTI_FACTOR_AUTHENTICATION]
 
         self._handshake = handshake
 
@@ -392,7 +393,7 @@ class MySQLConnection(MySQLConnectionAbstract):
                 self._ssl,
                 self._conn_attrs,
             )
-            self.set_converter_class(self._converter_class)
+            self.converter_class = self._converter_class
 
             if self._client_flags & ClientFlag.COMPRESS:
                 # update the network layer accordingly
@@ -447,7 +448,6 @@ class MySQLConnection(MySQLConnectionAbstract):
             pass  # Getting an exception would mean we are disconnected.
 
     def close(self) -> None:
-        """Disconnect from the MySQL server"""
         if self._span and self._span.is_recording():
             # pylint: disable=possibly-used-before-assignment
             record_exception_event(self._span, sys.exc_info()[1])
@@ -587,11 +587,11 @@ class MySQLConnection(MySQLConnectionAbstract):
 
         Returns a dict()
         """
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             ok_pkt = self._protocol.parse_ok(packet)
             self._handle_server_status(ok_pkt["status_flag"])
             return ok_pkt
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
         raise InterfaceError("Expected OK packet")
 
@@ -604,11 +604,11 @@ class MySQLConnection(MySQLConnectionAbstract):
 
         Returns a dict()
         """
-        if packet[4] == 254:
+        if packet[4] == EOF_STATUS:
             eof = self._protocol.parse_eof(packet)
             self._handle_server_status(eof["status_flag"])
             return eof
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
         raise InterfaceError("Expected EOF packet")
 
@@ -620,7 +620,49 @@ class MySQLConnection(MySQLConnectionAbstract):
         write_timeout: Optional[int] = None,
     ) -> OkPacketType:
         """Handle a LOAD DATA INFILE LOCAL request"""
+        if self._local_infile_filenames is None:
+            self._local_infile_filenames = get_local_infile_filenames(self._query)
+            if not self._local_infile_filenames:
+                raise InterfaceError(
+                    "No `LOCAL INFILE` statements found in the client's request. "
+                    "Check your request includes valid `LOCAL INFILE` statements."
+                )
+        elif not self._local_infile_filenames:
+            raise InterfaceError(
+                "Got more `LOCAL INFILE` responses than number of `LOCAL INFILE` "
+                "statements specified in the client's request. Please, report this "
+                "issue to the development team."
+            )
+
         file_name = os.path.abspath(filename)
+        file_name_from_request = os.path.abspath(self._local_infile_filenames.popleft())
+
+        # Verify the file location specified by `filename` from client's request exists
+        if not os.path.exists(file_name_from_request):
+            raise InterfaceError(
+                f"Location specified by filename {file_name_from_request} "
+                "from client's request does not exist."
+            )
+
+        # Verify the file location specified by `filename` from server's response exists
+        if not os.path.exists(file_name):
+            raise InterfaceError(
+                f"Location specified by filename {file_name} from server's "
+                "response does not exist."
+            )
+
+        # Verify the `filename` specified by server's response matches the one from
+        # the client's request.
+        try:
+            if not os.path.samefile(file_name, file_name_from_request):
+                raise InterfaceError(
+                    f"Filename {file_name} from the server's response is not the same "
+                    f"as filename {file_name_from_request} from the "
+                    "client's request."
+                )
+        except OSError as err:
+            raise InterfaceError from err
+
         if os.path.islink(file_name):
             raise OperationalError("Use of symbolic link is not allowed")
         if not self._allow_local_infile and not self._allow_local_infile_in_path:
@@ -692,14 +734,14 @@ class MySQLConnection(MySQLConnectionAbstract):
         """
         if not packet or len(packet) < 4:
             raise InterfaceError("Empty response")
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             return self._handle_ok(packet)
-        if packet[4] == 251:
+        if packet[4] == LOCAL_INFILE_STATUS:
             filename = packet[5:].decode()
             return self._handle_load_data_infile(filename, read_timeout, write_timeout)
-        if packet[4] == 254:
+        if packet[4] == EOF_STATUS:
             return self._handle_eof(packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
 
         # We have a text result set
@@ -850,6 +892,11 @@ class MySQLConnection(MySQLConnectionAbstract):
             if isinstance(query, str):
                 query = query.encode("utf-8")
             query = bytearray(query)
+
+        # Set/Reset internal state related to query execution
+        self._query = query
+        self._local_infile_filenames = None
+
         # Prepare query attrs
         charset = self.charset if self.charset != "utf8mb4" else "utf8"
         packet = bytearray()
@@ -1238,6 +1285,12 @@ class MySQLConnection(MySQLConnectionAbstract):
         """
         self._allow_local_infile_in_path = path
 
+    @MySQLConnectionAbstract.use_unicode.setter  # type: ignore
+    def use_unicode(self, value: bool) -> None:
+        self._use_unicode = value
+        if self.converter:
+            self.converter.set_unicode(value)
+
     def reset_session(
         self,
         user_variables: Optional[Dict[str, Any]] = None,
@@ -1322,7 +1375,6 @@ class MySQLConnection(MySQLConnectionAbstract):
         prepared: Optional[bool] = None,
         cursor_class: Optional[Type[MySQLCursor]] = None,  # type: ignore[override]
         dictionary: Optional[bool] = None,
-        named_tuple: Optional[bool] = None,
         read_timeout: Optional[int] = None,
         write_timeout: Optional[int] = None,
     ) -> MySQLCursor:
@@ -1331,9 +1383,9 @@ class MySQLConnection(MySQLConnectionAbstract):
         By default, MySQLCursor is returned. Depending on the options
         while connecting, a buffered and/or raw cursor is instantiated
         instead. Also depending upon the cursor options, rows can be
-        returned as dictionary or named tuple.
+        returned as a dictionary or a tuple.
 
-        Dictionary and namedtuple based cursors are available with buffered
+        Dictionary based cursors are available with buffered
         output but not raw.
 
         It is possible to also give a custom cursor through the
@@ -1376,8 +1428,6 @@ class MySQLConnection(MySQLConnectionAbstract):
             cursor_type |= 2
         if dictionary is True:
             cursor_type |= 4
-        if named_tuple is True:
-            cursor_type |= 8
         if prepared is True:
             cursor_type |= 16
 
@@ -1388,23 +1438,16 @@ class MySQLConnection(MySQLConnectionAbstract):
             3: MySQLCursorBufferedRaw,
             4: MySQLCursorDict,
             5: MySQLCursorBufferedDict,
-            8: MySQLCursorNamedTuple,
-            9: MySQLCursorBufferedNamedTuple,
             16: MySQLCursorPrepared,
-            18: MySQLCursorPreparedRaw,
             20: MySQLCursorPreparedDict,
-            24: MySQLCursorPreparedNamedTuple,
         }
         try:
-            raise_warning_against_deprecated_cursor_class(
-                cursor_name=types[cursor_type].__name__
-            )
             return (types[cursor_type])(self, read_timeout, write_timeout)
         except KeyError:
-            args = ("buffered", "raw", "dictionary", "named_tuple", "prepared")
+            args = ("buffered", "raw", "dictionary", "prepared")
             raise ValueError(
                 "Cursor not available with given criteria: "
-                + ", ".join([args[i] for i in range(5) if cursor_type & (1 << i) != 0])
+                + ", ".join([args[i] for i in range(4) if cursor_type & (1 << i) != 0])
             ) from None
 
     def commit(self) -> None:
@@ -1450,9 +1493,9 @@ class MySQLConnection(MySQLConnectionAbstract):
 
         Returns a dict()
         """
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             return self._protocol.parse_binary_prepare_ok(packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
         raise InterfaceError("Expected Binary OK packet")
 
@@ -1475,11 +1518,11 @@ class MySQLConnection(MySQLConnectionAbstract):
         """
         if not packet or len(packet) < 4:
             raise InterfaceError("Empty response")
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             return self._handle_ok(packet)
-        if packet[4] == 254:
+        if packet[4] == EOF_STATUS:
             return self._handle_eof(packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
 
         # We have a binary result set
