@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014, 2024, Oracle and/or its affiliates.
+# Copyright (c) 2014, 2025, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -39,8 +39,6 @@ import sys
 import unittest
 import warnings
 
-from collections import namedtuple
-
 import tests
 
 from mysql.connector import errorcode, errors
@@ -58,8 +56,6 @@ from mysql.connector.cursor_cext import (
     CMySQLCursorBuffered,
     CMySQLCursorPrepared,
     CMySQLCursorPreparedDict,
-    CMySQLCursorPreparedNamedTuple,
-    CMySQLCursorPreparedRaw,
     CMySQLCursorRaw,
 )
 
@@ -1165,277 +1161,3 @@ class CMySQLCursorPreparedDictTests(CMySQLCursorPreparedTests):
         self.assertEqual(len(rows), 4)
         self.assertEqual(rows[0], dict(zip(self.column_names, self.exp)))
         self.assertEqual(rows[1], dict(zip(self.column_names, self.exp)))
-
-
-class CMySQLCursorPreparedNamedTupleTests(CMySQLCursorPreparedTests):
-    tbl = "prep_named_tuple_stmt"
-
-    column_names = (
-        "my_null",
-        "my_bit",
-        "my_tinyint",
-        "my_smallint",
-        "my_mediumint",
-        "my_int",
-        "my_bigint",
-        "my_decimal",
-        "my_float",
-        "my_double",
-        "my_date",
-        "my_time",
-        "my_datetime",
-        "my_year",
-        "my_char",
-        "my_varchar",
-        "my_enum",
-        "my_geometry",
-        "my_blob",
-    )
-    named_tuple = namedtuple("Row", column_names)
-
-    def setUp(self):
-        config = tests.get_mysql_config()
-        self.cnx = CMySQLConnection(**config)
-        self.cur = self.cnx.cursor(prepared=True, named_tuple=True)
-        self.cur.execute(self.create_table_stmt.format(self.tbl))
-
-    def tearDown(self):
-        self.cur.execute("DROP TABLE IF EXISTS {0}".format(self.tbl))
-        self.cur.close()
-        self.cnx.close()
-
-    def test___init__(self):
-        self.assertIsInstance(self.cur, CMySQLCursorPreparedNamedTuple)
-
-    def test_close(self):
-        cur = self.cnx.cursor(prepared=True, named_tuple=True)
-        self.assertEqual(None, cur._stmt)
-        cur.close()
-
-    def test_fetchone(self):
-        self.cur.execute(self.insert_stmt.format(self.tbl), self.data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        row = self.cur.fetchone()
-        self.assertEqual(row[1:], self.named_tuple(*self.exp))
-        row = self.cur.fetchone()
-        self.assertIsNone(row)
-
-    def test_fetchall(self):
-        data = [self.data[:], self.data[:], self.data[:]]
-        self.cur.executemany(self.insert_stmt.format(self.tbl), data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 3)
-        for row in rows:
-            self.assertEqual(row[1:], self.named_tuple(*self.exp))
-
-    def test_fetchmany(self):
-        data = [self.data[:], self.data[:], self.data[:]]
-        self.cur.executemany(self.insert_stmt.format(self.tbl), data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        rows = self.cur.fetchmany(size=2)
-        self.assertEqual(len(rows), 2)
-        for row in rows:
-            self.assertEqual(row[1:], self.named_tuple(*self.exp))
-
-        rows = self.cur.fetchmany(1)
-        self.assertEqual(len(rows), 1)
-        self.assertEqual(rows[0][1:], self.named_tuple(*self.exp))
-
-    def test_execute(self):
-        # Use dict as placeholders
-        data_dict = dict(zip(self.insert_columns, self.data))
-
-        self.cur.execute(self.insert_dict_stmt.format(self.tbl), data_dict)
-        self.cur.execute(f"SELECT * FROM {self.tbl}")
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 1)
-        self.assertEqual(rows[0][1:], self.named_tuple(*self.exp))
-
-    def test_executemany(self):
-        data = [self.data[:], self.data[:]]
-        self.cur.executemany(self.insert_stmt.format(self.tbl), data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 2)
-        for row in rows:
-            self.assertEqual(row[1:], self.named_tuple(*self.exp))
-
-        # Use dict as placeholders
-        data_dict = dict(zip(self.insert_columns, self.data))
-        data = [data_dict, copy.deepcopy(data_dict)]
-
-        self.cur.executemany(self.insert_dict_stmt.format(self.tbl), data)
-        self.cur.execute(f"SELECT * FROM {self.tbl}")
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 4)
-        for row in rows:
-            self.assertEqual(row[1:], self.named_tuple(*self.exp))
-
-
-class CMySQLCursorPreparedRawTests(CMySQLCursorPreparedTests):
-    tbl = "prep_raw_stmt"
-
-    column_names = (
-        "my_null",
-        "my_bit",
-        "my_tinyint",
-        "my_smallint",
-        "my_mediumint",
-        "my_int",
-        "my_bigint",
-        "my_decimal",
-        "my_float",
-        "my_double",
-        "my_date",
-        "my_time",
-        "my_datetime",
-        "my_year",
-        "my_char",
-        "my_varchar",
-        "my_enum",
-        "my_geometry",
-        "my_blob",
-    )
-
-    def setUp(self):
-        config = tests.get_mysql_config()
-        self.cnx = CMySQLConnection(**config)
-        self.cur = self.cnx.cursor(prepared=True, raw=True)
-        self.cur.execute(self.create_table_stmt.format(self.tbl))
-
-    def tearDown(self):
-        self.cur.execute("DROP TABLE IF EXISTS {0}".format(self.tbl))
-        self.cur.close()
-        self.cnx.close()
-
-    def test___init__(self):
-        self.assertIsInstance(self.cur, CMySQLCursorPreparedRaw)
-
-    def test_close(self):
-        cur = self.cnx.cursor(prepared=True, raw=True)
-        self.assertEqual(None, cur._stmt)
-        cur.close()
-
-    def test_fetchone(self):
-        self.cur.execute(self.insert_stmt.format(self.tbl), self.data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        row = self.cur.fetchone()
-        self.assertEqual(row[1:], self.exp)
-        row = self.cur.fetchone()
-        self.assertIsNone(row)
-
-    def test_fetchall(self):
-        data = [self.data[:], self.data[:], self.data[:]]
-        self.cur.executemany(self.insert_stmt.format(self.tbl), data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 3)
-        for row in rows:
-            self.assertEqual(row[1:], self.exp)
-
-    def test_fetchmany(self):
-        data = [self.data[:], self.data[:], self.data[:]]
-        self.cur.executemany(self.insert_stmt.format(self.tbl), data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        rows = self.cur.fetchmany(size=2)
-        self.assertEqual(len(rows), 2)
-        for row in rows:
-            self.assertEqual(row[1:], self.exp)
-
-        rows = self.cur.fetchmany(1)
-        self.assertEqual(len(rows), 1)
-        self.assertEqual(rows[0][1:], self.exp)
-
-    def test_execute(self):
-        # Use dict as placeholders
-        data_dict = dict(zip(self.insert_columns, self.data))
-
-        self.cur.execute(self.insert_dict_stmt.format(self.tbl), data_dict)
-        self.cur.execute(f"SELECT * FROM {self.tbl}")
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 1)
-        self.assertEqual(rows[0][1:], self.exp)
-
-    def test_executemany(self):
-        data = [self.data[:], self.data[:]]
-        self.cur.executemany(self.insert_stmt.format(self.tbl), data)
-        self.cur.execute("SELECT * FROM {0}".format(self.tbl))
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 2)
-        for row in rows:
-            self.assertEqual(row[1:], self.exp)
-
-        # Use dict as placeholders
-        data_dict = dict(zip(self.insert_columns, self.data))
-        data = [data_dict, copy.deepcopy(data_dict)]
-
-        self.cur.executemany(self.insert_dict_stmt.format(self.tbl), data)
-        self.cur.execute(f"SELECT * FROM {self.tbl}")
-        rows = self.cur.fetchall()
-        self.assertEqual(len(rows), 4)
-        for row in rows:
-            self.assertEqual(row[1:], self.exp)
-
-
-class CMySQLCursorDeprecatedTests(tests.CMySQLCursorTests):
-
-    def test_deprecation_cursor_prepared_raw(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(prepared=True, raw=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
-
-    def test_deprecation_cursor_named_tuple(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(named_tuple=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
-
-    def test_deprecation_cursor_buffered_named_tuple(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(buffered=True, named_tuple=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
-
-    def test_deprecation_cursor_prepared_named_tuple(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(prepared=True, named_tuple=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
