@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009, 2024, Oracle and/or its affiliates.
+# Copyright (c) 2009, 2025, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -44,9 +44,7 @@ to be created first.
 import datetime
 import re
 import time
-import warnings
 
-from collections import namedtuple
 from decimal import Decimal
 
 import tests
@@ -646,20 +644,19 @@ class MySQLCursorTests(tests.TestsCursor):
         self._test_execute_cleanup(self.cnx, tbl)
         self.cur.close()
 
-    def test_fetchwarnings(self):
-        """MySQLCursor object fetchwarnings()-method"""
-        self.check_method(self.cur, "fetchwarnings")
+    def test_warnings(self):
+        """MySQLCursor object warnings-property"""
 
         self.assertEqual(
             None,
-            self.cur.fetchwarnings(),
+            self.cur.warnings,
             "There should be no warnings after initiating cursor.",
         )
 
         exp = ["A warning"]
         self.cur._warnings = exp
         self.cur._warning_count = len(self.cur._warnings)
-        self.assertEqual(exp, self.cur.fetchwarnings())
+        self.assertEqual(exp, self.cur.warnings)
         self.cur.close()
 
     def test_stored_results(self):
@@ -1412,98 +1409,6 @@ class MySQLCursorBufferedDictTests(tests.TestsCursor):
         self.assertEqual(exp, self.cur.fetchall())
 
 
-class MySQLCursorNamedTupleTests(tests.TestsCursor):
-    def setUp(self):
-        config = tests.get_mysql_config()
-
-        self.connection = connection.MySQLConnection(**config)
-        self.cur = self.connection.cursor(named_tuple=True)
-        self.cur.execute("DROP TABLE IF EXISTS MySQLCursorNamedTupleTests")
-        self.cur.execute(
-            "CREATE TABLE MySQLCursorNamedTupleTests(id INT(10) PRIMARY KEY,"
-            "name VARCHAR(20), city VARCHAR(20))"
-        )
-
-    def tearDown(self):
-        self.cur.execute("DROP TABLE IF EXISTS MySQLCursorNamedTupleTests")
-        self.cur.close()
-        self.connection.close()
-
-    def test_fetchone(self):
-        self.check_method(self.cur, "fetchone")
-
-        self.assertEqual(None, self.cur.fetchone())
-
-        self.cur.execute(
-            "INSERT INTO MySQLCursorNamedTupleTests VALUES(%s, %s, %s)",
-            (1, "ham", "spam"),
-        )
-
-        self.cur.execute("SELECT * FROM MySQLCursorNamedTupleTests")
-        named_tuple = namedtuple("Row", ["id", "name", "city"])
-        exp = named_tuple(1, "ham", "spam")
-        row = self.cur.fetchone()
-
-        self.assertEqual(exp.id, row.id)
-        self.assertEqual(exp.name, row.name)
-        self.assertEqual(exp.city, row.city)
-
-
-class MySQLCursorBufferedNamedTupleTests(tests.TestsCursor):
-    def setUp(self):
-        config = tests.get_mysql_config()
-
-        self.connection = connection.MySQLConnection(**config)
-        self.cur = self.connection.cursor(named_tuple=True, buffered=True)
-        self.cur.execute("DROP TABLE IF EXISTS MySQLCursorBufferedNamedTupleTests")
-        self.cur.execute(
-            "CREATE TABLE MySQLCursorBufferedNamedTupleTests("
-            "id INT(10) PRIMARY KEY, name VARCHAR(20), city VARCHAR(20))"
-        )
-
-    def tearDown(self):
-        self.cur.execute("DROP TABLE IF EXISTS MySQLCursorBufferedNamedTupleTests")
-
-        self.cur.close()
-        self.connection.close()
-
-    def test_fetchone(self):
-        self.check_method(self.cur, "fetchone")
-
-        self.assertEqual(None, self.cur.fetchone())
-        self.cur.execute(
-            "INSERT INTO MySQLCursorBufferedNamedTupleTests VALUES(%s, %s, %s)",
-            (1, "ham", "spam"),
-        )
-
-        self.cur.execute("SELECT * FROM MySQLCursorBufferedNamedTupleTests")
-        named_tuple = namedtuple("Row", ["id", "name", "city"])
-        exp = named_tuple(1, "ham", "spam")
-        row = self.cur.fetchone()
-
-        self.assertEqual(exp.id, row.id)
-        self.assertEqual(exp.name, row.name)
-        self.assertEqual(exp.city, row.city)
-
-    def test_fetchall(self):
-        self.check_method(self.cur, "fetchall")
-
-        self.assertRaises(errors.InterfaceError, self.cur.fetchall)
-        self.cur.execute(
-            "INSERT INTO MySQLCursorBufferedNamedTupleTests VALUES(%s, %s, %s)",
-            (1, "ham", "spam"),
-        )
-
-        self.cur.execute("SELECT * FROM MySQLCursorBufferedNamedTupleTests")
-        named_tuple = namedtuple("Row", ["id", "name", "city"])
-        exp = named_tuple(1, "ham", "spam")
-        row = self.cur.fetchall()
-
-        self.assertEqual(exp.id, row[0].id)
-        self.assertEqual(exp.name, row[0].name)
-        self.assertEqual(exp.city, row[0].city)
-
-
 class MySQLCursorPreparedDictTests(tests.TestsCursor):
     table_name = "MySQLCursorPreparedDictTests"
     column_names = ("id", "name", "city")
@@ -1564,198 +1469,3 @@ class MySQLCursorPreparedDictTests(tests.TestsCursor):
         self.cur.execute(f"SELECT * FROM {self.table_name}")
         exp = [dict(zip(self.column_names, data)) for data in self.data]
         self.assertEqual(exp, self.cur.fetchall())
-
-
-class MySQLCursorPreparedNamedTupleTests(tests.TestsCursor):
-    table_name = "MySQLCursorPreparedNamedTupleTests"
-    column_names = ("id", "name", "city")
-    data = [
-        (1, "Mr A", "mexico"),
-        (2, "Mr B", "portugal"),
-        (3, "Mr C", "poland"),
-        (4, "Mr D", "usa"),
-    ]
-    named_tuple = namedtuple("Row", column_names)
-
-    def setUp(self):
-        config = tests.get_mysql_config()
-        self.cnx = connection.MySQLConnection(**config)
-        self.cur = self.cnx.cursor(prepared=True, named_tuple=True)
-        self.cur.execute(f"DROP TABLE IF EXISTS {self.table_name}")
-        self.cur.execute(
-            f"CREATE TABLE {self.table_name}(id INT(10) PRIMARY KEY, name "
-            "VARCHAR(20), city VARCHAR(20))"
-        )
-
-    def tearDown(self):
-        self.cur.execute(f"DROP TABLE IF EXISTS {self.table_name}")
-        self.cur.close()
-        self.cnx.close()
-
-    def test_fetchone(self):
-        self.cur.execute(
-            f"INSERT INTO {self.table_name} VALUES(%s, %s, %s)",
-            self.data[0],
-        )
-
-        self.cur.execute(f"SELECT * FROM {self.table_name}")
-        exp = self.named_tuple(*self.data[0])
-        self.assertEqual(exp, self.cur.fetchone())
-
-    def test_fetchmany(self):
-        for row in self.data:
-            self.cur.execute(
-                f"INSERT INTO {self.table_name} VALUES(%s, %s, %s)",
-                row,
-            )
-
-        self.cur.execute(f"SELECT * FROM {self.table_name}")
-
-        exp = [self.named_tuple(*data) for data in self.data[:2]]
-        self.assertEqual(exp, self.cur.fetchmany(size=2))
-
-        exp = [self.named_tuple(*data) for data in self.data[2:]]
-        self.assertEqual(exp, self.cur.fetchmany(size=2))
-
-    def test_fetchall(self):
-        for row in self.data:
-            self.cur.execute(
-                f"INSERT INTO {self.table_name} VALUES(%s, %s, %s)",
-                row,
-            )
-
-        self.cur.execute(f"SELECT * FROM {self.table_name}")
-        exp = [self.named_tuple(*data) for data in self.data]
-        self.assertEqual(exp, self.cur.fetchall())
-
-
-class MySQLCursorPreparedRawTests(tests.TestsCursor):
-    table_name = "MySQLCursorPreparedRawTests"
-    column_names = ("id", "name", "city")
-    data = [
-        (1, "Mr A", "mexico"),
-        (2, "Mr B", "portugal"),
-        (3, "Mr C", "poland"),
-        (4, "Mr D", "usa"),
-    ]
-
-    def setUp(self):
-        config = tests.get_mysql_config()
-        self.cnx = connection.MySQLConnection(**config)
-        self.cur = self.cnx.cursor(prepared=True, raw=True)
-        self.cur.execute(f"DROP TABLE IF EXISTS {self.table_name}")
-        self.cur.execute(
-            f"CREATE TABLE {self.table_name}(id INT(10) PRIMARY KEY, name "
-            "VARCHAR(20), city VARCHAR(20))"
-        )
-
-    def tearDown(self):
-        self.cur.execute(f"DROP TABLE IF EXISTS {self.table_name}")
-        self.cur.close()
-        self.cnx.close()
-
-    def test_fetchone(self):
-        self.cur.execute(
-            f"INSERT INTO {self.table_name} VALUES(%s, %s, %s)",
-            self.data[0],
-        )
-
-        self.cur.execute(f"SELECT * FROM {self.table_name}")
-        exp = self.data[0]
-        self.assertEqual(exp, self.cur.fetchone())
-
-    def test_fetchmany(self):
-        for row in self.data:
-            self.cur.execute(
-                f"INSERT INTO {self.table_name} VALUES(%s, %s, %s)",
-                row,
-            )
-
-        self.cur.execute(f"SELECT * FROM {self.table_name}")
-
-        exp = self.data[:2]
-        self.assertEqual(exp, self.cur.fetchmany(size=2))
-
-        exp = self.data[2:]
-        self.assertEqual(exp, self.cur.fetchmany(size=2))
-
-    def test_fetchall(self):
-        for row in self.data:
-            self.cur.execute(
-                f"INSERT INTO {self.table_name} VALUES(%s, %s, %s)",
-                row,
-            )
-
-        self.cur.execute(f"SELECT * FROM {self.table_name}")
-        exp = self.data[:]
-        self.assertEqual(exp, self.cur.fetchall())
-
-
-class MySQLCursorDeprecatedTests(tests.TestsCursor):
-
-    def setUp(self):
-        config = tests.get_mysql_config()
-        self.cnx = connection.MySQLConnection(**config)
-
-    def tearDown(self):
-        self.cnx.close()
-
-    def test_deprecation_cursor_prepared_raw(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(prepared=True, raw=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
-
-    def test_deprecation_cursor_named_tuple(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(named_tuple=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
-
-    def test_deprecation_cursor_buffered_named_tuple(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(buffered=True, named_tuple=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
-
-    def test_deprecation_cursor_prepared_named_tuple(self):
-        with warnings.catch_warnings(record=True) as warnings_stack:
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always", DeprecationWarning)
-            # The warning should be raised as the cursor is instantiated
-            with self.cnx.cursor(prepared=True, named_tuple=True) as _:
-                pass
-            self.assertTrue(
-                len(warnings_stack) != 0,
-                msg="No warnings were caught as warnings_stack was empty",
-            )
-            self.assertTrue(issubclass(warnings_stack[-1].category, DeprecationWarning))
-            self.assertTrue("deprecated" in str(warnings_stack[-1].message))
-            warnings.resetwarnings()
